#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 void
version:              0.7.4
visibility:           public
id:                   void-0.7.4-Ab78HEYVlxC2PerDGXO6Wd
key:                  void-0.7.4-Ab78HEYVlxC2PerDGXO6Wd
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            portable
homepage:             http://github.com/ekmett/void
synopsis:             A Haskell 98 logically uninhabited data type
description:
    A Haskell 98 logically uninhabited data type, used to indicate that a given term should not exist.

category:             Data Structures
abi:                  968187bd3a74a44d17aaab6da19bcf21
exposed:              True
exposed-modules:      Data.Void.Unsafe
import-dirs:          /usr/lib/ghc-9.6.6/site-local/void-0.7.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/void-0.7.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/void-0.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-void
hs-libraries:         HSvoid-0.7.4-Ab78HEYVlxC2PerDGXO6Wd
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-void/html/void.haddock
haddock-html:         /usr/share/doc/haskell-void/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

